==> curia-4.2.0b7.tar.gz: curia-4.2.0b7/src/curia/api/docs/ModelResponseDto.md <==
# ModelResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project** | [**ModelJoinedProjectResponseDto**](ModelJoinedProjectResponseDto.md) |  | [optional] 
**model_jobs** | [**ModelJoinedModelJobResponseDto**](ModelJoinedModelJobResponseDto.md) |  | [optional] 
**cohorts** | [**ModelJoinedCohortResponseDto**](ModelJoinedCohortResponseDto.md) |  | [optional] 
**user_favorites** | [**ModelJoinedUserFavoriteResponseDto**](ModelJoinedUserFavoriteResponseDto.md) |  | [optional] 
**model_output_details** | [**ModelJoinedModelOutputDetailsResponseDto**](ModelJoinedModelOutputDetailsResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**feature_store** | **str** |  | 
**description** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 
**children_last_updated_at** | **datetime** |  | [optional] 
**children_last_updated_by** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> curia-4.6.0.tar.gz: curia-4.6.0/src/curia/api/docs/ModelResponseDto.md <==
# ModelResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project** | [**ModelJoinedProjectResponseDto**](ModelJoinedProjectResponseDto.md) |  | [optional] 
**model_jobs** | [**list[ModelJoinedModelJobResponseDto]**](ModelJoinedModelJobResponseDto.md) |  | [optional] 
**cohorts** | [**list[ModelJoinedCohortResponseDto]**](ModelJoinedCohortResponseDto.md) |  | [optional] 
**user_favorites** | [**list[ModelJoinedUserFavoriteResponseDto]**](ModelJoinedUserFavoriteResponseDto.md) |  | [optional] 
**model_output_details** | [**ModelJoinedModelOutputDetailsResponseDto**](ModelJoinedModelOutputDetailsResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**feature_store** | **str** |  | 
**description** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 
**children_last_updated_at** | **datetime** |  | [optional] 
**children_last_updated_by** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
